#------------------------------------------------------------------------------------------#
# FILE: Analysis.Experiment1.R                                                             #  
#------------------------------------------------------------------------------------------#   

# Clear the R environment:
rm(list=ls(all=TRUE))

# Load the RJAGS library:
library(rjags)

# Set the working directory to root folder of our analysis:  
setwd("[path-to-files]")

# Load the data for the second experiment (data are stored in an R-binary)
load("Experiment2.R.data")

# Load the JAGS models: 
source("models/Paper1.Experiment2.Model0.R") 
source("models/Paper1.Experiment2.Model1.R")  
source("models/Paper1.Experiment2.Model2.R")
source("models/Paper1.Experiment2.Model3.R")
 
#Load models into a list:
MODELS      <- list()
MODELS[[1]] <- Paper1.Experiment2.Model0()
MODELS[[2]] <- Paper1.Experiment2.Model1()
MODELS[[3]] <- Paper1.Experiment2.Model2()
MODELS[[4]] <- Paper1.Experiment2.Model3()

#Data 
DATA <- list(
    dS          = Experiment2$dS  / 100,
    dW          = Experiment2$dW  / 100,
    dIs         = Experiment2$dIs / 100,
    dIns        = Experiment2$dIns/ 100,
    nObs        = 6100,
    nSubjects   = 305,
    GameID      = Experiment2$Game,
    denominator = tabulate(Experiment2$Game),
    Y           = Experiment2$CHOICE, 
    SID         = Experiment2$Subject
)

FIT <- list(); SAMPLES <- list(); DIC <- list()
 
iterations <- 50000
thin <- 5

for(i in 1:4){
    paste0("Model ", i)

    # Fit the JAGS model
    FIT[[i]] <- jags.model(MODELS[[i]], data=DATA, n.chains=2, n.adapt=iterations)
    
    # Update the model
    update(FIT[[i]], iterations)
    
    # Draw samples    
    SAMPLES[[i]] <- coda.samples(FIT[[i]],variable.names=c("mon","item"),n.iter=iterations, thin=thin)
    
    # Draw samples for the DIC    
    DIC[[i]] <- dic.samples(FIT[[i]],iterations,thin=thin)
}

# Compare DIC of all models.
DDIC <- list()

for(i in 1:4){
    DDIC[[i]] <-list()
    
    for(j in 1:4){
        DDIC[[i]][[j]]<- diffdic(DIC[[i]],DIC[[j]])   
    }
}
 
# Save output files:  
save(SAMPLES, file="Experiment2.Output.SAMPLES")
save(DIC,     file="Experiment2.Output.DIC")
save(DDIC,    file="Experiment2.Output.DDIC")


