// Initialize Stata
version 13.1
clear all
set more off
cd "[path to data files]"

use Experiment2-Data.dta, replace 
 
// Scale variables to ease estimation: 
replace dS   = dS   / 100
replace dW   = dW   / 100
replace dIs  = dIs  / 100
replace dIns = dIns / 100

// Note: in the data for Experiment 2, the CHOICE variable is (directly) coded as:
//				 1 = option X is chosen (the left option on screen),
//				 0 = option Y is chosen (the right option on screen. )

gsem (CHOICE <- dS c.dW    c.dW#L1[Subject] /// 
                   c.dIs   c.dIs#L2[Subject] ///
				   c.dIns  c.dIns#L3[Subject], nocons family(binomial) link(probit)), latent(L1 L2 L3 )

est replay, coeflegend				   

	//   Relevant options: 
	//    	(-) 	",nocons"  is needed to suppress the intercept; our model does not include one. 
	//    	(-) 	"family(binomial) link(probit)" makes the gsem-model an unscaled probit model. 
	//      (-)     "latent(L1 L2 L3)" is needed to tell gsem explicitly which variables are to be treated as latent. 
	
	//   Relevant defaults: 
	//      (-)     gsem per default estimates variances and covariances of and between latent parameters. 
    //              no restrictions are placed on these parameters, other than that the covariance matrix needs to be positive. 
		

		
// Means of social motives:
nlcom (  _b[CHOICE:dW]   / _b[CHOICE:dS]  		                                                                 ) ///
      (  _b[CHOICE:dIs]  / _b[CHOICE:dS]                                                                         ) ///
      (  _b[CHOICE:dIns] / _b[CHOICE:dS] 	                                                                     ) ///
	  (   sqrt(_b[var(L1[Subject]):_cons])/_b[CHOICE:dS]                                                         ) ///
	  (   sqrt(_b[var(L2[Subject]):_cons])/_b[CHOICE:dS]                                                         ) ///
	  (   sqrt(_b[var(L3[Subject]):_cons])/_b[CHOICE:dS]  	                                                     ) ///
      ( (_b[cov(L1[Subject],L2[Subject]):_cons])/(sqrt(_b[var(L1[Subject]):_cons] * _b[var(L2[Subject]):_cons])) ) ///
      ( (_b[cov(L1[Subject],L3[Subject]):_cons])/(sqrt(_b[var(L1[Subject]):_cons] * _b[var(L3[Subject]):_cons])) ) ///
      ( (_b[cov(L2[Subject],L3[Subject]):_cons])/(sqrt(_b[var(L2[Subject]):_cons] * _b[var(L3[Subject]):_cons])) ) ///
	  ( 1 / _b[CHOICE:dS]  ) 
  